@@ -13,7 +13,7 @@
 ##############################################################################
 """Bootstrap tests
 
-$Id: tests.py 95575 2009-01-30 15:26:00Z thefunny42 $
+$Id: tests.py 101171 2009-06-20 19:05:45Z icemac $
 """
 import ZConfig
 import os
@@ -30,20 +30,24 @@ from zope.traversing.api import traverse, getPath
 from zope.error.interfaces import IErrorReportingUtility
 from zope.error.error import ErrorReportingUtility
 
-from zope.app.component.testing import PlacefulSetup
 from zope.site import hooks
 from zope.site.folder import rootFolder, Folder
 from zope.site.interfaces import IRootFolder
 from zope.app.publication.zopepublication import ZopePublication
-from zope.app.component.site import LocalSiteManager
+from zope.site.site import LocalSiteManager
 
 from zope.app.appsetup.bootstrap import bootStrapSubscriber
 from zope.app.appsetup.bootstrap import getInformationFromEvent, \
      ensureObject, ensureUtility
-from zope.app.appsetup.interfaces import DatabaseOpened
+from zope.processlifetime import DatabaseOpened
 from zope.app.appsetup.errorlog import bootStrapSubscriber as errorlogBootStrapSubscriber
+from zope.app.appsetup.session import bootStrapSubscriber as sessionBootstrapSubscriber
+from zope.session.interfaces import IClientIdManager
+from zope.session.interfaces import ISessionDataContainer
 
 from zope.app.testing import placelesssetup
+from zope.app.testing import setup
+
 
 class EventStub(object):
 
@@ -54,15 +58,15 @@ class EventStub(object):
 # TODO: some methods from the boostap module are not tested
 #
 
-class TestBootstrapSubscriber(PlacefulSetup, unittest.TestCase):
+class TestBootstrapSubscriber(placelesssetup.PlacelessSetup, unittest.TestCase):
 
     def setUp(self):
-        PlacefulSetup.setUp(self)
+        setup.placefulSetUp()
         self.db = DB()
 
     def tearDown(self):
         transaction.abort()
-        PlacefulSetup.tearDown(self)
+        setup.placefulTearDown()
         self.db.close()
 
     def createRootFolder(self):
@@ -110,7 +114,7 @@ class TestBootstrapSubscriber(PlacefulSetup, unittest.TestCase):
         sub_folder = root_folder['sub_folder']
         ensureUtility(sub_folder, IErrorReportingUtility,
                      'ErrorReporting', ErrorReportingUtility,
-                     'ErrorReporting', asObject=True)
+                     'ErrorReporting')
 
         # Make sure it was created on the sub folder, not the root folder
         got_utility = zope.component.getUtility(IErrorReportingUtility,
@@ -131,10 +135,10 @@ class TestBootstrapSubscriber(PlacefulSetup, unittest.TestCase):
             cx = self.db.open()
             utility = ensureUtility(root_folder, IErrorReportingUtility,
                                     'ErrorReporting', ErrorReportingUtility,
-                                    'ErrorReporting', asObject=True)
+                                    'ErrorReporting')
             utility2 = ensureUtility(root_folder, IErrorReportingUtility,
                                      'ErrorReporting2', ErrorReportingUtility,
-                                     'ErrorReporting2', asObject=True)
+                                     'ErrorReporting2')
             if utility != None:
                 name = utility.__name__
                 name2 = utility2.__name__
@@ -169,7 +173,7 @@ class TestBootstrapSubscriber(PlacefulSetup, unittest.TestCase):
         """
         self.createRFAndSM()
 
-        event = DatabaseOpened(self.db)        
+        event = DatabaseOpened(self.db)
         # this will open and close the database by itself
         errorlogBootStrapSubscriber(event)
 
@@ -182,7 +186,27 @@ class TestBootstrapSubscriber(PlacefulSetup, unittest.TestCase):
         # we need to close again in the end
         connection.close()
 
-        
+    def test_bootstrapSusbcriber(self):
+        self.createRFAndSM()
+
+        event = DatabaseOpened(self.db)
+        # this will open and close the database by itself
+        sessionBootstrapSubscriber(event)
+
+        db, connection, root, root_folder = getInformationFromEvent(event)
+
+        got_utility = zope.component.getUtility(IClientIdManager,
+                                                context=root_folder)
+        self.failUnless(IClientIdManager.providedBy(got_utility))
+
+        got_utility = zope.component.getUtility(ISessionDataContainer,
+                                                context=root_folder)
+        self.failUnless(ISessionDataContainer.providedBy(got_utility))
+
+        # we need to close again in the end
+        connection.close()
+
+
 class TestConfigurationSchema(unittest.TestCase):
 
     def setUp(self):
